@@ -17,7 +17,6 @@ import binascii
 import functools
 import json
 import os
-import re
 import shlex
 import time
 
@@ -47,7 +46,7 @@ WARN_BIOSDEVNAME_NOT_FOUND = False
 UNIT_CONVERTER = pint.UnitRegistry(filename=None)
 UNIT_CONVERTER.define('bytes = []')
 UNIT_CONVERTER.define('MB = 1048576 bytes')
-_MEMORY_ID_RE = re.compile(r'^memory(:\d+)?$')
+
 NODE = None
 
 
@@ -72,7 +71,7 @@ def _get_system_lshw_dict():
 
     :return: A python dict from the lshw json output
     """
-    out, _e = utils.execute('lshw', '-quiet', '-json', log_stdout=False)
+    out, _e = utils.execute('lshw', '-quiet', '-json')
     return json.loads(out)
 
 
@@ -261,15 +260,17 @@ class BlockDevice(encoding.SerializableComparable):
 
 class NetworkInterface(encoding.SerializableComparable):
     serializable_fields = ('name', 'mac_address', 'ipv4_address',
-                           'has_carrier', 'lldp', 'vendor', 'product',
-                           'client_id', 'biosdevname')
+                           'ipv6_address', 'has_carrier', 'lldp',
+                           'vendor', 'product', 'client_id',
+                           'biosdevname')
 
-    def __init__(self, name, mac_addr, ipv4_address=None, has_carrier=True,
-                 lldp=None, vendor=None, product=None, client_id=None,
-                 biosdevname=None):
+    def __init__(self, name, mac_addr, ipv4_address=None, ipv6_address=None,
+                 has_carrier=True, lldp=None, vendor=None, product=None,
+                 client_id=None, biosdevname=None):
         self.name = name
         self.mac_address = mac_addr
         self.ipv4_address = ipv4_address
+        self.ipv6_address = ipv6_address
         self.has_carrier = has_carrier
         self.lldp = lldp
         self.vendor = vendor
@@ -575,14 +576,15 @@ class GenericHardwareManager(HardwareManager):
             return self.lldp_data.get(interface_name)
 
     def get_interface_info(self, interface_name):
-        addr_path = '{}/class/net/{}/address'.format(self.sys_path,
-                                                     interface_name)
-        with open(addr_path) as addr_file:
-            mac_addr = addr_file.read().strip()
+
+        mac_addr = netutils.get_mac_addr(interface_name)
+        if mac_addr is None:
+            raise errors.IncompatibleHardwareMethodError()
 
         return NetworkInterface(
             interface_name, mac_addr,
             ipv4_address=self.get_ipv4_addr(interface_name),
+            ipv6_address=self.get_ipv6_addr(interface_name),
             has_carrier=netutils.interface_has_carrier(interface_name),
             vendor=_get_device_info(interface_name, 'net', 'vendor'),
             product=_get_device_info(interface_name, 'net', 'device'),
@@ -591,6 +593,14 @@ class GenericHardwareManager(HardwareManager):
     def get_ipv4_addr(self, interface_id):
         return netutils.get_ipv4_addr(interface_id)
 
+    def get_ipv6_addr(self, interface_id):
+        """Get the default IPv6 address assigned to the interface.
+
+        With different networking environment, the address could be a
+        link-local address, ULA or something else.
+        """
+        return netutils.get_ipv6_addr(interface_id)
+
     def get_bios_given_nic_name(self, interface_name):
         """Collect the BIOS given NICs name.
 
@@ -696,13 +706,11 @@ class GenericHardwareManager(HardwareManager):
             for sys_child in sys_dict['children']:
                 if sys_child['id'] == 'core':
                     for core_child in sys_child['children']:
-                        if _MEMORY_ID_RE.match(core_child['id']):
-                            for bank in core_child.get('children', ()):
-                                if bank.get('size'):
-                                    value = ("%(size)s %(units)s" % bank)
-                                    physical += int(UNIT_CONVERTER(value).to
-                                                    ('MB').magnitude)
-
+                        if core_child['id'] == 'memory':
+                            if core_child.get('size'):
+                                value = "%(size)s %(units)s" % core_child
+                                physical += int(UNIT_CONVERTER(value).to(
+                                    'MB').magnitude)
             if not physical:
                 LOG.warning('Did not find any physical RAM')
 
@@ -754,7 +762,7 @@ class GenericHardwareManager(HardwareManager):
         try:
             sys_dict = _get_system_lshw_dict()
         except (processutils.ProcessExecutionError, OSError, ValueError) as e:
-            LOG.warning('Could not retrieve vendor info from lshw: %s', e)
+            LOG.warning('Could not retrieve vendor info from lshw: %e', e)
             sys_dict = {}
         return SystemVendorInfo(product_name=sys_dict.get('product', ''),
                                 serial_number=sys_dict.get('serial', ''),
@@ -774,14 +782,15 @@ class GenericHardwareManager(HardwareManager):
             LOG.info("Skipping the erase of virtual media device %s",
                      block_device.name)
             return
-
+        info = node.get('driver_internal_info', {})
         # Note(TheJulia) Use try/except to capture and log the failure
         # and then revert to attempting to shred the volume if enabled.
         try:
-            if self._ata_erase(block_device):
+            execute_secure_erase = info.get(
+                'agent_enable_ata_secure_erase', True)
+            if execute_secure_erase and self._ata_erase(block_device):
                 return
         except errors.BlockDeviceEraseError as e:
-            info = node.get('driver_internal_info', {})
             execute_shred = info.get(
                 'agent_continue_if_ata_erase_failed', False)
             if execute_shred:
@@ -1042,7 +1051,7 @@ class GenericHardwareManager(HardwareManager):
             # types of communication media and protocols and effectively used
             for channel in range(1, 8):
                 out, e = utils.execute(
-                    "ipmitool lan print {} | awk '/IP Address[ \\t]*:/"
+                    "ipmitool lan print {} | awk '/IP Address[[:space:]]*:/"
                     " {{print $4}}'".format(channel), shell=True)
                 if e.startswith("Invalid channel"):
                     continue
